# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/authorization_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/authorization_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\027AuthorizationErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n>google/ads/googleads_v1/proto/errors/authorization_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xdb\x02\n\x16\x41uthorizationErrorEnum\"\xc0\x02\n\x12\x41uthorizationError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16USER_PERMISSION_DENIED\x10\x02\x12#\n\x1f\x44\x45VELOPER_TOKEN_NOT_WHITELISTED\x10\x03\x12\x1e\n\x1a\x44\x45VELOPER_TOKEN_PROHIBITED\x10\x04\x12\x14\n\x10PROJECT_DISABLED\x10\x05\x12\x17\n\x13\x41UTHORIZATION_ERROR\x10\x06\x12\x18\n\x14\x41\x43TION_NOT_PERMITTED\x10\x07\x12\x15\n\x11INCOMPLETE_SIGNUP\x10\x08\x12\x18\n\x14\x43USTOMER_NOT_ENABLED\x10\x18\x12\x0f\n\x0bMISSING_TOS\x10\t\x12 \n\x1c\x44\x45VELOPER_TOKEN_NOT_APPROVED\x10\nB\xf2\x01\n\"com.google.ads.googleads.v1.errorsB\x17\x41uthorizationErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_AUTHORIZATIONERRORENUM_AUTHORIZATIONERROR = _descriptor.EnumDescriptor(
  name='AuthorizationError',
  full_name='google.ads.googleads.v1.errors.AuthorizationErrorEnum.AuthorizationError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_PERMISSION_DENIED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVELOPER_TOKEN_NOT_WHITELISTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVELOPER_TOKEN_PROHIBITED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_DISABLED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_ERROR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_NOT_PERMITTED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOMPLETE_SIGNUP', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_ENABLED', index=9, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_TOS', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVELOPER_TOKEN_NOT_APPROVED', index=11, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=156,
  serialized_end=476,
)
_sym_db.RegisterEnumDescriptor(_AUTHORIZATIONERRORENUM_AUTHORIZATIONERROR)


_AUTHORIZATIONERRORENUM = _descriptor.Descriptor(
  name='AuthorizationErrorEnum',
  full_name='google.ads.googleads.v1.errors.AuthorizationErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTHORIZATIONERRORENUM_AUTHORIZATIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=476,
)

_AUTHORIZATIONERRORENUM_AUTHORIZATIONERROR.containing_type = _AUTHORIZATIONERRORENUM
DESCRIPTOR.message_types_by_name['AuthorizationErrorEnum'] = _AUTHORIZATIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthorizationErrorEnum = _reflection.GeneratedProtocolMessageType('AuthorizationErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.authorization_error_pb2'
  ,
  __doc__ = """Container for enum describing possible authorization errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.AuthorizationErrorEnum)
  ))
_sym_db.RegisterMessage(AuthorizationErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/ad_group_criterion_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/ad_group_criterion_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\032AdGroupCriterionErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/errors/ad_group_criterion_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xd7\x0c\n\x19\x41\x64GroupCriterionErrorEnum\"\xb9\x0c\n\x15\x41\x64GroupCriterionError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12+\n\'AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST\x10\x02\x12+\n\'AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS\x10\x03\x12*\n&CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION\x10\x04\x12\x17\n\x13TOO_MANY_OPERATIONS\x10\x05\x12\x18\n\x14\x43\x41NT_UPDATE_NEGATIVE\x10\x06\x12\x1a\n\x16\x43ONCRETE_TYPE_REQUIRED\x10\x07\x12!\n\x1d\x42ID_INCOMPATIBLE_WITH_ADGROUP\x10\x08\x12\x1d\n\x19\x43\x41NNOT_TARGET_AND_EXCLUDE\x10\t\x12\x0f\n\x0bILLEGAL_URL\x10\n\x12\x18\n\x14INVALID_KEYWORD_TEXT\x10\x0b\x12\x1b\n\x17INVALID_DESTINATION_URL\x10\x0c\x12\x1f\n\x1bMISSING_DESTINATION_URL_TAG\x10\r\x12\x31\n-KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM\x10\x0e\x12\x17\n\x13INVALID_USER_STATUS\x10\x0f\x12\x1c\n\x18\x43\x41NNOT_ADD_CRITERIA_TYPE\x10\x10\x12 \n\x1c\x43\x41NNOT_EXCLUDE_CRITERIA_TYPE\x10\x11\x12\x35\n1CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE\x10\x1b\x12-\n)OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS\x10\x1c\x12\x34\n0CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS\x10\x1d\x12!\n\x1d\x43\x41NNOT_SET_WITHOUT_FINAL_URLS\x10\x1e\x12\x36\n2CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST\x10\x1f\x12\x33\n/CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST\x10 \x12;\n7CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS\x10!\x12:\n6CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST\x10\"\x12\x32\n.CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS\x10#\x12=\n9CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE\x10$\x12/\n+FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE\x10%\x12\x36\n2FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE\x10&\x12#\n\x1fINVALID_LISTING_GROUP_HIERARCHY\x10\'\x12+\n\'LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN\x10(\x12\x32\n.LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE\x10)\x12:\n6LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS\x10*\x12 \n\x1cLISTING_GROUP_ALREADY_EXISTS\x10+\x12 \n\x1cLISTING_GROUP_DOES_NOT_EXIST\x10,\x12#\n\x1fLISTING_GROUP_CANNOT_BE_REMOVED\x10-\x12\x1e\n\x1aINVALID_LISTING_GROUP_TYPE\x10.\x12*\n&LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID\x10/B\xf5\x01\n\"com.google.ads.googleads.v2.errorsB\x1a\x41\x64GroupCriterionErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_ADGROUPCRITERIONERRORENUM_ADGROUPCRITERIONERROR = _descriptor.EnumDescriptor(
  name='AdGroupCriterionError',
  full_name='google.ads.googleads.v2.errors.AdGroupCriterionErrorEnum.AdGroupCriterionError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_OPERATIONS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANT_UPDATE_NEGATIVE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCRETE_TYPE_REQUIRED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_INCOMPATIBLE_WITH_ADGROUP', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_TARGET_AND_EXCLUDE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ILLEGAL_URL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_KEYWORD_TEXT', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DESTINATION_URL', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DESTINATION_URL_TAG', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_STATUS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_CRITERIA_TYPE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXCLUDE_CRITERIA_TYPE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE', index=18, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS', index=19, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS', index=20, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_WITHOUT_FINAL_URLS', index=21, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST', index=22, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST', index=23, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS', index=24, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST', index=25, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS', index=26, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE', index=27, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE', index=28, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE', index=29, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LISTING_GROUP_HIERARCHY', index=30, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN', index=31, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE', index=32, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS', index=33, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_ALREADY_EXISTS', index=34, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_DOES_NOT_EXIST', index=35, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_CANNOT_BE_REMOVED', index=36, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LISTING_GROUP_TYPE', index=37, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID', index=38, number=47,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=164,
  serialized_end=1757,
)
_sym_db.RegisterEnumDescriptor(_ADGROUPCRITERIONERRORENUM_ADGROUPCRITERIONERROR)


_ADGROUPCRITERIONERRORENUM = _descriptor.Descriptor(
  name='AdGroupCriterionErrorEnum',
  full_name='google.ads.googleads.v2.errors.AdGroupCriterionErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADGROUPCRITERIONERRORENUM_ADGROUPCRITERIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=1757,
)

_ADGROUPCRITERIONERRORENUM_ADGROUPCRITERIONERROR.containing_type = _ADGROUPCRITERIONERRORENUM
DESCRIPTOR.message_types_by_name['AdGroupCriterionErrorEnum'] = _ADGROUPCRITERIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupCriterionErrorEnum = _reflection.GeneratedProtocolMessageType('AdGroupCriterionErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPCRITERIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.ad_group_criterion_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ad group criterion errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.AdGroupCriterionErrorEnum)
  ))
_sym_db.RegisterMessage(AdGroupCriterionErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import keyword_plan_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2


class KeywordPlanServiceStub(object):
  """Proto file describing the keyword plan service.

  Service to manage keyword plans.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlan = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GetKeywordPlan',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GetKeywordPlanRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2.KeywordPlan.FromString,
        )
    self.MutateKeywordPlans = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/MutateKeywordPlans',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansResponse.FromString,
        )
    self.GenerateForecastMetrics = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GenerateForecastMetrics',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsResponse.FromString,
        )
    self.GenerateHistoricalMetrics = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanService/GenerateHistoricalMetrics',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsResponse.FromString,
        )


class KeywordPlanServiceServicer(object):
  """Proto file describing the keyword plan service.

  Service to manage keyword plans.
  """

  def GetKeywordPlan(self, request, context):
    """Returns the requested plan in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlans(self, request, context):
    """Creates, updates, or removes keyword plans. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateForecastMetrics(self, request, context):
    """Returns the requested Keyword Plan forecasts.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateHistoricalMetrics(self, request, context):
    """Returns the requested Keyword Plan historical metrics.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlan': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlan,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GetKeywordPlanRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__pb2.KeywordPlan.SerializeToString,
      ),
      'MutateKeywordPlans': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlans,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.MutateKeywordPlansResponse.SerializeToString,
      ),
      'GenerateForecastMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateForecastMetrics,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateForecastMetricsResponse.SerializeToString,
      ),
      'GenerateHistoricalMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateHistoricalMetrics,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__service__pb2.GenerateHistoricalMetricsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.KeywordPlanService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_budget.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import budget_delivery_method_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__delivery__method__pb2
from google.ads.google_ads.v1.proto.enums import budget_period_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__period__pb2
from google.ads.google_ads.v1.proto.enums import budget_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__status__pb2
from google.ads.google_ads.v1.proto.enums import budget_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_budget.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\023CampaignBudgetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n=google/ads/googleads_v1/proto/resources/campaign_budget.proto\x12!google.ads.googleads.v1.resources\x1a@google/ads/googleads_v1/proto/enums/budget_delivery_method.proto\x1a\x37google/ads/googleads_v1/proto/enums/budget_period.proto\x1a\x37google/ads/googleads_v1/proto/enums/budget_status.proto\x1a\x35google/ads/googleads_v1/proto/enums/budget_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8f\t\n\x0e\x43\x61mpaignBudget\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\ramount_micros\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13total_amount_micros\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\x06status\x18\x06 \x01(\x0e\x32<.google.ads.googleads.v1.enums.BudgetStatusEnum.BudgetStatus\x12\x65\n\x0f\x64\x65livery_method\x18\x07 \x01(\x0e\x32L.google.ads.googleads.v1.enums.BudgetDeliveryMethodEnum.BudgetDeliveryMethod\x12\x35\n\x11\x65xplicitly_shared\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0freference_count\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x16has_recommended_budget\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n recommended_budget_amount_micros\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\x06period\x18\r \x01(\x0e\x32<.google.ads.googleads.v1.enums.BudgetPeriodEnum.BudgetPeriod\x12V\n1recommended_budget_estimated_change_weekly_clicks\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12[\n6recommended_budget_estimated_change_weekly_cost_micros\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\\\n7recommended_budget_estimated_change_weekly_interactions\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12U\n0recommended_budget_estimated_change_weekly_views\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n\x04type\x18\x12 \x01(\x0e\x32\x38.google.ads.googleads.v1.enums.BudgetTypeEnum.BudgetTypeB\x80\x02\n%com.google.ads.googleads.v1.resourcesB\x13\x43\x61mpaignBudgetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__delivery__method__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__period__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNBUDGET = _descriptor.Descriptor(
  name='CampaignBudget',
  full_name='google.ads.googleads.v1.resources.CampaignBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignBudget.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.CampaignBudget.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.CampaignBudget.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_micros', full_name='google.ads.googleads.v1.resources.CampaignBudget.amount_micros', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount_micros', full_name='google.ads.googleads.v1.resources.CampaignBudget.total_amount_micros', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CampaignBudget.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delivery_method', full_name='google.ads.googleads.v1.resources.CampaignBudget.delivery_method', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicitly_shared', full_name='google.ads.googleads.v1.resources.CampaignBudget.explicitly_shared', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_count', full_name='google.ads.googleads.v1.resources.CampaignBudget.reference_count', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_recommended_budget', full_name='google.ads.googleads.v1.resources.CampaignBudget.has_recommended_budget', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_amount_micros', full_name='google.ads.googleads.v1.resources.CampaignBudget.recommended_budget_amount_micros', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='period', full_name='google.ads.googleads.v1.resources.CampaignBudget.period', index=11,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_estimated_change_weekly_clicks', full_name='google.ads.googleads.v1.resources.CampaignBudget.recommended_budget_estimated_change_weekly_clicks', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_estimated_change_weekly_cost_micros', full_name='google.ads.googleads.v1.resources.CampaignBudget.recommended_budget_estimated_change_weekly_cost_micros', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_estimated_change_weekly_interactions', full_name='google.ads.googleads.v1.resources.CampaignBudget.recommended_budget_estimated_change_weekly_interactions', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommended_budget_estimated_change_weekly_views', full_name='google.ads.googleads.v1.resources.CampaignBudget.recommended_budget_estimated_change_weekly_views', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.CampaignBudget.type', index=16,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=1565,
)

_CAMPAIGNBUDGET.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNBUDGET.fields_by_name['amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['total_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__status__pb2._BUDGETSTATUSENUM_BUDGETSTATUS
_CAMPAIGNBUDGET.fields_by_name['delivery_method'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__delivery__method__pb2._BUDGETDELIVERYMETHODENUM_BUDGETDELIVERYMETHOD
_CAMPAIGNBUDGET.fields_by_name['explicitly_shared'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGNBUDGET.fields_by_name['reference_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['has_recommended_budget'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CAMPAIGNBUDGET.fields_by_name['recommended_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['period'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__period__pb2._BUDGETPERIODENUM_BUDGETPERIOD
_CAMPAIGNBUDGET.fields_by_name['recommended_budget_estimated_change_weekly_clicks'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['recommended_budget_estimated_change_weekly_cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['recommended_budget_estimated_change_weekly_interactions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['recommended_budget_estimated_change_weekly_views'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBUDGET.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_budget__type__pb2._BUDGETTYPEENUM_BUDGETTYPE
DESCRIPTOR.message_types_by_name['CampaignBudget'] = _CAMPAIGNBUDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignBudget = _reflection.GeneratedProtocolMessageType('CampaignBudget', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBUDGET,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_budget_pb2'
  ,
  __doc__ = """A campaign budget.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign budget. Campaign budget
          resource names have the form:
          ``customers/{customer_id}/campaignBudgets/{budget_id}``
      id:
          The ID of the campaign budget.  A campaign budget is created
          using the CampaignBudgetService create operation and is
          assigned a budget ID. A budget ID can be shared across
          different campaigns; the system will then allocate the
          campaign budget among different campaigns to get optimum
          results.
      name:
          The name of the campaign budget.  When creating a campaign
          budget through CampaignBudgetService, every explicitly shared
          campaign budget must have a non-null, non-empty name. Campaign
          budgets that are not explicitly shared derive their name from
          the attached campaign's name.  The length of this string must
          be between 1 and 255, inclusive, in UTF-8 bytes, (trimmed).
      amount_micros:
          The amount of the budget, in the local currency for the
          account. Amount is specified in micros, where one million is
          equivalent to one currency unit. Monthly spend is capped at
          30.4 times this amount.
      total_amount_micros:
          The lifetime amount of the budget, in the local currency for
          the account. Amount is specified in micros, where one million
          is equivalent to one currency unit.
      status:
          The status of this campaign budget. This field is read-only.
      delivery_method:
          The delivery method that determines the rate at which the
          campaign budget is spent.  Defaults to STANDARD if unspecified
          in a create operation.
      explicitly_shared:
          Specifies whether the budget is explicitly shared. Defaults to
          true if unspecified in a create operation.  If true, the
          budget was created with the purpose of sharing across one or
          more campaigns.  If false, the budget was created with the
          intention of only being used with a single campaign. The
          budget's name and status will stay in sync with the campaign's
          name and status. Attempting to share the budget with a second
          campaign will result in an error.  A non-shared budget can
          become an explicitly shared. The same operation must also
          assign the budget a name.  A shared campaign budget can never
          become non-shared.
      reference_count:
          The number of campaigns actively using the budget.  This field
          is read-only.
      has_recommended_budget:
          Indicates whether there is a recommended budget for this
          campaign budget.  This field is read-only.
      recommended_budget_amount_micros:
          The recommended budget amount. If no recommendation is
          available, this will be set to the budget amount. Amount is
          specified in micros, where one million is equivalent to one
          currency unit.  This field is read-only.
      period:
          Period over which to spend the budget. Defaults to DAILY if
          not specified.
      recommended_budget_estimated_change_weekly_clicks:
          The estimated change in weekly clicks if the recommended
          budget is applied.  This field is read-only.
      recommended_budget_estimated_change_weekly_cost_micros:
          The estimated change in weekly cost in micros if the
          recommended budget is applied. One million is equivalent to
          one currency unit.  This field is read-only.
      recommended_budget_estimated_change_weekly_interactions:
          The estimated change in weekly interactions if the recommended
          budget is applied.  This field is read-only.
      recommended_budget_estimated_change_weekly_views:
          The estimated change in weekly views if the recommended budget
          is applied.  This field is read-only.
      type:
          The type of the campaign budget.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignBudget)
  ))
_sym_db.RegisterMessage(CampaignBudget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import keyword_plan_ad_group_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_ad_group_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2


class KeywordPlanAdGroupServiceStub(object):
  """Proto file describing the keyword plan ad group service.

  Service to manage Keyword Plan ad groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlanAdGroup = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanAdGroupService/GetKeywordPlanAdGroup',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.GetKeywordPlanAdGroupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2.KeywordPlanAdGroup.FromString,
        )
    self.MutateKeywordPlanAdGroups = channel.unary_unary(
        '/google.ads.googleads.v1.services.KeywordPlanAdGroupService/MutateKeywordPlanAdGroups',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.MutateKeywordPlanAdGroupsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.MutateKeywordPlanAdGroupsResponse.FromString,
        )


class KeywordPlanAdGroupServiceServicer(object):
  """Proto file describing the keyword plan ad group service.

  Service to manage Keyword Plan ad groups.
  """

  def GetKeywordPlanAdGroup(self, request, context):
    """Returns the requested Keyword Plan ad group in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlanAdGroups(self, request, context):
    """Creates, updates, or removes Keyword Plan ad groups. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanAdGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlanAdGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlanAdGroup,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.GetKeywordPlanAdGroupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_keyword__plan__ad__group__pb2.KeywordPlanAdGroup.SerializeToString,
      ),
      'MutateKeywordPlanAdGroups': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlanAdGroups,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.MutateKeywordPlanAdGroupsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_keyword__plan__ad__group__service__pb2.MutateKeywordPlanAdGroupsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.KeywordPlanAdGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/targeting_setting.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import targeting_dimension_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/targeting_setting.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\025TargetingSettingProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/common/targeting_setting.proto\x12\x1egoogle.ads.googleads.v1.common\x1a=google/ads/googleads_v1/proto/enums/targeting_dimension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"b\n\x10TargetingSetting\x12N\n\x13target_restrictions\x18\x01 \x03(\x0b\x32\x31.google.ads.googleads.v1.common.TargetRestriction\"\xa8\x01\n\x11TargetRestriction\x12\x65\n\x13targeting_dimension\x18\x01 \x01(\x0e\x32H.google.ads.googleads.v1.enums.TargetingDimensionEnum.TargetingDimension\x12,\n\x08\x62id_only\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xf0\x01\n\"com.google.ads.googleads.v1.commonB\x15TargetingSettingProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_TARGETINGSETTING = _descriptor.Descriptor(
  name='TargetingSetting',
  full_name='google.ads.googleads.v1.common.TargetingSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_restrictions', full_name='google.ads.googleads.v1.common.TargetingSetting.target_restrictions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=319,
)


_TARGETRESTRICTION = _descriptor.Descriptor(
  name='TargetRestriction',
  full_name='google.ads.googleads.v1.common.TargetRestriction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='targeting_dimension', full_name='google.ads.googleads.v1.common.TargetRestriction.targeting_dimension', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_only', full_name='google.ads.googleads.v1.common.TargetRestriction.bid_only', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=490,
)

_TARGETINGSETTING.fields_by_name['target_restrictions'].message_type = _TARGETRESTRICTION
_TARGETRESTRICTION.fields_by_name['targeting_dimension'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_targeting__dimension__pb2._TARGETINGDIMENSIONENUM_TARGETINGDIMENSION
_TARGETRESTRICTION.fields_by_name['bid_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['TargetingSetting'] = _TARGETINGSETTING
DESCRIPTOR.message_types_by_name['TargetRestriction'] = _TARGETRESTRICTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TargetingSetting = _reflection.GeneratedProtocolMessageType('TargetingSetting', (_message.Message,), dict(
  DESCRIPTOR = _TARGETINGSETTING,
  __module__ = 'google.ads.googleads_v1.proto.common.targeting_setting_pb2'
  ,
  __doc__ = """Settings for the targeting related features, at Campaign and AdGroup
  level.
  
  
  Attributes:
      target_restrictions:
          The per-targeting-dimension setting to restrict the reach of
          your campaign or ad group.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetingSetting)
  ))
_sym_db.RegisterMessage(TargetingSetting)

TargetRestriction = _reflection.GeneratedProtocolMessageType('TargetRestriction', (_message.Message,), dict(
  DESCRIPTOR = _TARGETRESTRICTION,
  __module__ = 'google.ads.googleads_v1.proto.common.targeting_setting_pb2'
  ,
  __doc__ = """The list of per-targeting-dimension targeting settings.
  
  
  Attributes:
      targeting_dimension:
          The targeting dimension that these settings apply to.
      bid_only:
          Indicates whether to restrict your ads to show only for the
          criteria you have selected for this targeting\_dimension, or
          to target all values for this targeting\_dimension and show
          ads based on your targeting in other TargetingDimensions. A
          value of 'true' means that these criteria will only apply bid
          modifiers, and not affect targeting. A value of 'false' means
          that these criteria will restrict targeting as well as
          applying bid modifiers.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TargetRestriction)
  ))
_sym_db.RegisterMessage(TargetRestriction)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import feed_item_target_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2
from google.ads.google_ads.v2.proto.services import feed_item_target_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2


class FeedItemTargetServiceStub(object):
  """Proto file describing the FeedItemTarget service.

  Service to manage feed item targets.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetFeedItemTarget = channel.unary_unary(
        '/google.ads.googleads.v2.services.FeedItemTargetService/GetFeedItemTarget',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.GetFeedItemTargetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2.FeedItemTarget.FromString,
        )
    self.MutateFeedItemTargets = channel.unary_unary(
        '/google.ads.googleads.v2.services.FeedItemTargetService/MutateFeedItemTargets',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.MutateFeedItemTargetsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.MutateFeedItemTargetsResponse.FromString,
        )


class FeedItemTargetServiceServicer(object):
  """Proto file describing the FeedItemTarget service.

  Service to manage feed item targets.
  """

  def GetFeedItemTarget(self, request, context):
    """Returns the requested feed item targets in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateFeedItemTargets(self, request, context):
    """Creates or removes feed item targets. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FeedItemTargetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetFeedItemTarget': grpc.unary_unary_rpc_method_handler(
          servicer.GetFeedItemTarget,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.GetFeedItemTargetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2.FeedItemTarget.SerializeToString,
      ),
      'MutateFeedItemTargets': grpc.unary_unary_rpc_method_handler(
          servicer.MutateFeedItemTargets,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.MutateFeedItemTargetsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__target__service__pb2.MutateFeedItemTargetsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.FeedItemTargetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import campaign_experiment_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2
from google.ads.google_ads.v2.proto.services import campaign_experiment_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CampaignExperimentServiceStub(object):
  """Proto file describing the Campaign Experiment service.

  CampaignExperimentService manages the life cycle of campaign experiments.
  It is used to create new experiments from drafts, modify experiment
  properties, promote changes in an experiment back to its base campaign,
  graduate experiments into new stand-alone campaigns, and to remove an
  experiment.

  An experiment consists of two variants or arms - the base campaign and the
  experiment campaign, directing a fixed share of traffic to each arm.
  A campaign experiment is created from a draft of changes to the base campaign
  and will be a snapshot of changes in the draft at the time of creation.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignExperiment = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/GetCampaignExperiment',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GetCampaignExperimentRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2.CampaignExperiment.FromString,
        )
    self.CreateCampaignExperiment = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/CreateCampaignExperiment',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.CreateCampaignExperimentRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.MutateCampaignExperiments = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/MutateCampaignExperiments',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.MutateCampaignExperimentsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.MutateCampaignExperimentsResponse.FromString,
        )
    self.GraduateCampaignExperiment = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/GraduateCampaignExperiment',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GraduateCampaignExperimentRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GraduateCampaignExperimentResponse.FromString,
        )
    self.PromoteCampaignExperiment = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/PromoteCampaignExperiment',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.PromoteCampaignExperimentRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.EndCampaignExperiment = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/EndCampaignExperiment',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.EndCampaignExperimentRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.ListCampaignExperimentAsyncErrors = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignExperimentService/ListCampaignExperimentAsyncErrors',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.ListCampaignExperimentAsyncErrorsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.ListCampaignExperimentAsyncErrorsResponse.FromString,
        )


class CampaignExperimentServiceServicer(object):
  """Proto file describing the Campaign Experiment service.

  CampaignExperimentService manages the life cycle of campaign experiments.
  It is used to create new experiments from drafts, modify experiment
  properties, promote changes in an experiment back to its base campaign,
  graduate experiments into new stand-alone campaigns, and to remove an
  experiment.

  An experiment consists of two variants or arms - the base campaign and the
  experiment campaign, directing a fixed share of traffic to each arm.
  A campaign experiment is created from a draft of changes to the base campaign
  and will be a snapshot of changes in the draft at the time of creation.
  """

  def GetCampaignExperiment(self, request, context):
    """Returns the requested campaign experiment in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateCampaignExperiment(self, request, context):
    """Creates a campaign experiment based on a campaign draft. The draft campaign
    will be forked into a real campaign (called the experiment campaign) that
    will begin serving ads if successfully created.

    The campaign experiment is created immediately with status INITIALIZING.
    This method return a long running operation that tracks the forking of the
    draft campaign. If the forking fails, a list of errors can be retrieved
    using the ListCampaignExperimentAsyncErrors method. The operation's
    metadata will be a StringValue containing the resource name of the created
    campaign experiment.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignExperiments(self, request, context):
    """Updates campaign experiments. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GraduateCampaignExperiment(self, request, context):
    """Graduates a campaign experiment to a full campaign. The base and experiment
    campaigns will start running independently with their own budgets.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PromoteCampaignExperiment(self, request, context):
    """Promotes the changes in a experiment campaign back to the base campaign.

    The campaign experiment is updated immediately with status PROMOTING.
    This method return a long running operation that tracks the promoting of
    the experiment campaign. If the promoting fails, a list of errors can be
    retrieved using the ListCampaignExperimentAsyncErrors method.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EndCampaignExperiment(self, request, context):
    """Immediately ends a campaign experiment, changing the experiment's scheduled
    end date and without waiting for end of day. End date is updated to be the
    time of the request.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListCampaignExperimentAsyncErrors(self, request, context):
    """Returns all errors that occurred during CampaignExperiment create or
    promote (whichever occurred last).
    Supports standard list paging.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignExperimentServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignExperiment,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GetCampaignExperimentRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__experiment__pb2.CampaignExperiment.SerializeToString,
      ),
      'CreateCampaignExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.CreateCampaignExperiment,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.CreateCampaignExperimentRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'MutateCampaignExperiments': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignExperiments,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.MutateCampaignExperimentsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.MutateCampaignExperimentsResponse.SerializeToString,
      ),
      'GraduateCampaignExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.GraduateCampaignExperiment,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GraduateCampaignExperimentRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.GraduateCampaignExperimentResponse.SerializeToString,
      ),
      'PromoteCampaignExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.PromoteCampaignExperiment,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.PromoteCampaignExperimentRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'EndCampaignExperiment': grpc.unary_unary_rpc_method_handler(
          servicer.EndCampaignExperiment,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.EndCampaignExperimentRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'ListCampaignExperimentAsyncErrors': grpc.unary_unary_rpc_method_handler(
          servicer.ListCampaignExperimentAsyncErrors,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.ListCampaignExperimentAsyncErrorsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__experiment__service__pb2.ListCampaignExperimentAsyncErrorsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CampaignExperimentService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/recommendation_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/recommendation_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\030RecommendationErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n?google/ads/googleads_v1/proto/errors/recommendation_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xda\x03\n\x17RecommendationErrorEnum\"\xbe\x03\n\x13RecommendationError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1b\n\x17\x42UDGET_AMOUNT_TOO_SMALL\x10\x02\x12\x1b\n\x17\x42UDGET_AMOUNT_TOO_LARGE\x10\x03\x12\x19\n\x15INVALID_BUDGET_AMOUNT\x10\x04\x12\x10\n\x0cPOLICY_ERROR\x10\x05\x12\x16\n\x12INVALID_BID_AMOUNT\x10\x06\x12\x19\n\x15\x41\x44GROUP_KEYWORD_LIMIT\x10\x07\x12\"\n\x1eRECOMMENDATION_ALREADY_APPLIED\x10\x08\x12\x1e\n\x1aRECOMMENDATION_INVALIDATED\x10\t\x12\x17\n\x13TOO_MANY_OPERATIONS\x10\n\x12\x11\n\rNO_OPERATIONS\x10\x0b\x12!\n\x1d\x44IFFERENT_TYPES_NOT_SUPPORTED\x10\x0c\x12\x1b\n\x17\x44UPLICATE_RESOURCE_NAME\x10\r\x12$\n RECOMMENDATION_ALREADY_DISMISSED\x10\x0e\x12\x19\n\x15INVALID_APPLY_REQUEST\x10\x0f\x42\xf3\x01\n\"com.google.ads.googleads.v1.errorsB\x18RecommendationErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_RECOMMENDATIONERRORENUM_RECOMMENDATIONERROR = _descriptor.EnumDescriptor(
  name='RecommendationError',
  full_name='google.ads.googleads.v1.errors.RecommendationErrorEnum.RecommendationError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUDGET_AMOUNT_TOO_SMALL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUDGET_AMOUNT_TOO_LARGE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_BUDGET_AMOUNT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICY_ERROR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_BID_AMOUNT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP_KEYWORD_LIMIT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECOMMENDATION_ALREADY_APPLIED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECOMMENDATION_INVALIDATED', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_OPERATIONS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_OPERATIONS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENT_TYPES_NOT_SUPPORTED', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_RESOURCE_NAME', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECOMMENDATION_ALREADY_DISMISSED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_APPLY_REQUEST', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=158,
  serialized_end=604,
)
_sym_db.RegisterEnumDescriptor(_RECOMMENDATIONERRORENUM_RECOMMENDATIONERROR)


_RECOMMENDATIONERRORENUM = _descriptor.Descriptor(
  name='RecommendationErrorEnum',
  full_name='google.ads.googleads.v1.errors.RecommendationErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECOMMENDATIONERRORENUM_RECOMMENDATIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=604,
)

_RECOMMENDATIONERRORENUM_RECOMMENDATIONERROR.containing_type = _RECOMMENDATIONERRORENUM
DESCRIPTOR.message_types_by_name['RecommendationErrorEnum'] = _RECOMMENDATIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecommendationErrorEnum = _reflection.GeneratedProtocolMessageType('RecommendationErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _RECOMMENDATIONERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.recommendation_error_pb2'
  ,
  __doc__ = """Container for enum describing possible errors from applying a
  recommendation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.RecommendationErrorEnum)
  ))
_sym_db.RegisterMessage(RecommendationErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/ad_group_ad.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v1.proto.enums import ad_group_ad_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__status__pb2
from google.ads.google_ads.v1.proto.enums import ad_strength_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__strength__pb2
from google.ads.google_ads.v1.proto.enums import policy_approval_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__approval__status__pb2
from google.ads.google_ads.v1.proto.enums import policy_review_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__review__status__pb2
from google.ads.google_ads.v1.proto.resources import ad_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/ad_group_ad.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\016AdGroupAdProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n9google/ads/googleads_v1/proto/resources/ad_group_ad.proto\x12!google.ads.googleads.v1.resources\x1a\x31google/ads/googleads_v1/proto/common/policy.proto\x1a<google/ads/googleads_v1/proto/enums/ad_group_ad_status.proto\x1a\x35google/ads/googleads_v1/proto/enums/ad_strength.proto\x1a@google/ads/googleads_v1/proto/enums/policy_approval_status.proto\x1a>google/ads/googleads_v1/proto/enums/policy_review_status.proto\x1a\x30google/ads/googleads_v1/proto/resources/ad.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xfb\x02\n\tAdGroupAd\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12R\n\x06status\x18\x03 \x01(\x0e\x32\x42.google.ads.googleads.v1.enums.AdGroupAdStatusEnum.AdGroupAdStatus\x12.\n\x08\x61\x64_group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x02\x61\x64\x18\x05 \x01(\x0b\x32%.google.ads.googleads.v1.resources.Ad\x12Q\n\x0epolicy_summary\x18\x06 \x01(\x0b\x32\x39.google.ads.googleads.v1.resources.AdGroupAdPolicySummary\x12M\n\x0b\x61\x64_strength\x18\x07 \x01(\x0e\x32\x38.google.ads.googleads.v1.enums.AdStrengthEnum.AdStrength\"\xb0\x02\n\x16\x41\x64GroupAdPolicySummary\x12N\n\x14policy_topic_entries\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v1.common.PolicyTopicEntry\x12_\n\rreview_status\x18\x02 \x01(\x0e\x32H.google.ads.googleads.v1.enums.PolicyReviewStatusEnum.PolicyReviewStatus\x12\x65\n\x0f\x61pproval_status\x18\x03 \x01(\x0e\x32L.google.ads.googleads.v1.enums.PolicyApprovalStatusEnum.PolicyApprovalStatusB\xfb\x01\n%com.google.ads.googleads.v1.resourcesB\x0e\x41\x64GroupAdProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__strength__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__review__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ADGROUPAD = _descriptor.Descriptor(
  name='AdGroupAd',
  full_name='google.ads.googleads.v1.resources.AdGroupAd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AdGroupAd.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.AdGroupAd.status', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v1.resources.AdGroupAd.ad_group', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad', full_name='google.ads.googleads.v1.resources.AdGroupAd.ad', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_summary', full_name='google.ads.googleads.v1.resources.AdGroupAd.policy_summary', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_strength', full_name='google.ads.googleads.v1.resources.AdGroupAd.ad_strength', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=886,
)


_ADGROUPADPOLICYSUMMARY = _descriptor.Descriptor(
  name='AdGroupAdPolicySummary',
  full_name='google.ads.googleads.v1.resources.AdGroupAdPolicySummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_topic_entries', full_name='google.ads.googleads.v1.resources.AdGroupAdPolicySummary.policy_topic_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='review_status', full_name='google.ads.googleads.v1.resources.AdGroupAdPolicySummary.review_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_status', full_name='google.ads.googleads.v1.resources.AdGroupAdPolicySummary.approval_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=889,
  serialized_end=1193,
)

_ADGROUPAD.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__group__ad__status__pb2._ADGROUPADSTATUSENUM_ADGROUPADSTATUS
_ADGROUPAD.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADGROUPAD.fields_by_name['ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2._AD
_ADGROUPAD.fields_by_name['policy_summary'].message_type = _ADGROUPADPOLICYSUMMARY
_ADGROUPAD.fields_by_name['ad_strength'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__strength__pb2._ADSTRENGTHENUM_ADSTRENGTH
_ADGROUPADPOLICYSUMMARY.fields_by_name['policy_topic_entries'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_policy__pb2._POLICYTOPICENTRY
_ADGROUPADPOLICYSUMMARY.fields_by_name['review_status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__review__status__pb2._POLICYREVIEWSTATUSENUM_POLICYREVIEWSTATUS
_ADGROUPADPOLICYSUMMARY.fields_by_name['approval_status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__approval__status__pb2._POLICYAPPROVALSTATUSENUM_POLICYAPPROVALSTATUS
DESCRIPTOR.message_types_by_name['AdGroupAd'] = _ADGROUPAD
DESCRIPTOR.message_types_by_name['AdGroupAdPolicySummary'] = _ADGROUPADPOLICYSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupAd = _reflection.GeneratedProtocolMessageType('AdGroupAd', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPAD,
  __module__ = 'google.ads.googleads_v1.proto.resources.ad_group_ad_pb2'
  ,
  __doc__ = """An ad group ad.
  
  
  Attributes:
      resource_name:
          The resource name of the ad. Ad group ad resource names have
          the form:
          ``customers/{customer_id}/adGroupAds/{ad_group_id}~{ad_id}``
      status:
          The status of the ad.
      ad_group:
          The ad group to which the ad belongs.
      ad:
          The ad.
      policy_summary:
          Policy information for the ad.
      ad_strength:
          Overall ad strength for this ad group ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AdGroupAd)
  ))
_sym_db.RegisterMessage(AdGroupAd)

AdGroupAdPolicySummary = _reflection.GeneratedProtocolMessageType('AdGroupAdPolicySummary', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPADPOLICYSUMMARY,
  __module__ = 'google.ads.googleads_v1.proto.resources.ad_group_ad_pb2'
  ,
  __doc__ = """Contains policy information for an ad.
  
  
  Attributes:
      policy_topic_entries:
          The list of policy findings for this ad.
      review_status:
          Where in the review process this ad is.
      approval_status:
          The overall approval status of this ad, calculated based on
          the status of its individual policy topic entries.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AdGroupAdPolicySummary)
  ))
_sym_db.RegisterMessage(AdGroupAdPolicySummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/remarketing_action.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import tag_snippet_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/remarketing_action.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\026RemarketingActionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n@google/ads/googleads_v1/proto/resources/remarketing_action.proto\x12!google.ads.googleads.v1.resources\x1a\x36google/ads/googleads_v1/proto/common/tag_snippet.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc1\x01\n\x11RemarketingAction\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0ctag_snippets\x18\x04 \x03(\x0b\x32*.google.ads.googleads.v1.common.TagSnippetB\x83\x02\n%com.google.ads.googleads.v1.resourcesB\x16RemarketingActionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_REMARKETINGACTION = _descriptor.Descriptor(
  name='RemarketingAction',
  full_name='google.ads.googleads.v1.resources.RemarketingAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.RemarketingAction.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.RemarketingAction.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.RemarketingAction.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_snippets', full_name='google.ads.googleads.v1.resources.RemarketingAction.tag_snippets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=415,
)

_REMARKETINGACTION.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REMARKETINGACTION.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REMARKETINGACTION.fields_by_name['tag_snippets'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2._TAGSNIPPET
DESCRIPTOR.message_types_by_name['RemarketingAction'] = _REMARKETINGACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemarketingAction = _reflection.GeneratedProtocolMessageType('RemarketingAction', (_message.Message,), dict(
  DESCRIPTOR = _REMARKETINGACTION,
  __module__ = 'google.ads.googleads_v1.proto.resources.remarketing_action_pb2'
  ,
  __doc__ = """A remarketing action. A snippet of JavaScript code that will collect the
  product id and the type of page people visited (product page, shopping
  cart page, purchase page, general site visit) on an advertiser's
  website.
  
  
  Attributes:
      resource_name:
          The resource name of the remarketing action. Remarketing
          action resource names have the form:  ``customers/{customer_id
          }/remarketingActions/{remarketing_action_id}``
      id:
          Id of the remarketing action.
      name:
          The name of the remarketing action.  This field is required
          and should not be empty when creating new remarketing actions.
      tag_snippets:
          The snippets used for tracking remarketing actions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.RemarketingAction)
  ))
_sym_db.RegisterMessage(RemarketingAction)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/null_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/null_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\016NullErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/errors/null_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"L\n\rNullErrorEnum\";\n\tNullError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x10\n\x0cNULL_CONTENT\x10\x02\x42\xe9\x01\n\"com.google.ads.googleads.v2.errorsB\x0eNullErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_NULLERRORENUM_NULLERROR = _descriptor.EnumDescriptor(
  name='NullError',
  full_name='google.ads.googleads.v2.errors.NullErrorEnum.NullError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NULL_CONTENT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=136,
  serialized_end=195,
)
_sym_db.RegisterEnumDescriptor(_NULLERRORENUM_NULLERROR)


_NULLERRORENUM = _descriptor.Descriptor(
  name='NullErrorEnum',
  full_name='google.ads.googleads.v2.errors.NullErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NULLERRORENUM_NULLERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=195,
)

_NULLERRORENUM_NULLERROR.containing_type = _NULLERRORENUM
DESCRIPTOR.message_types_by_name['NullErrorEnum'] = _NULLERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NullErrorEnum = _reflection.GeneratedProtocolMessageType('NullErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _NULLERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.null_error_pb2'
  ,
  __doc__ = """Container for enum describing possible null errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.NullErrorEnum)
  ))
_sym_db.RegisterMessage(NullErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/criterion_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/criterion_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\023CriterionErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/errors/criterion_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xa8\x1d\n\x12\x43riterionErrorEnum\"\x91\x1d\n\x0e\x43riterionError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16\x43ONCRETE_TYPE_REQUIRED\x10\x02\x12\x1d\n\x19INVALID_EXCLUDED_CATEGORY\x10\x03\x12\x18\n\x14INVALID_KEYWORD_TEXT\x10\x04\x12\x19\n\x15KEYWORD_TEXT_TOO_LONG\x10\x05\x12\x1e\n\x1aKEYWORD_HAS_TOO_MANY_WORDS\x10\x06\x12\x1d\n\x19KEYWORD_HAS_INVALID_CHARS\x10\x07\x12\x19\n\x15INVALID_PLACEMENT_URL\x10\x08\x12\x15\n\x11INVALID_USER_LIST\x10\t\x12\x19\n\x15INVALID_USER_INTEREST\x10\n\x12$\n INVALID_FORMAT_FOR_PLACEMENT_URL\x10\x0b\x12\x1d\n\x19PLACEMENT_URL_IS_TOO_LONG\x10\x0c\x12\"\n\x1ePLACEMENT_URL_HAS_ILLEGAL_CHAR\x10\r\x12,\n(PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE\x10\x0e\x12\x39\n5PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION\x10\x0f\x12\x16\n\x12INVALID_TOPIC_PATH\x10\x10\x12\x1e\n\x1aINVALID_YOUTUBE_CHANNEL_ID\x10\x11\x12\x1c\n\x18INVALID_YOUTUBE_VIDEO_ID\x10\x12\x12\'\n#YOUTUBE_VERTICAL_CHANNEL_DEPRECATED\x10\x13\x12*\n&YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED\x10\x14\x12\x1b\n\x17YOUTUBE_URL_UNSUPPORTED\x10\x15\x12 \n\x1c\x43\x41NNOT_EXCLUDE_CRITERIA_TYPE\x10\x16\x12\x1c\n\x18\x43\x41NNOT_ADD_CRITERIA_TYPE\x10\x17\x12\x1a\n\x16INVALID_PRODUCT_FILTER\x10\x18\x12\x1b\n\x17PRODUCT_FILTER_TOO_LONG\x10\x19\x12$\n CANNOT_EXCLUDE_SIMILAR_USER_LIST\x10\x1a\x12\x1f\n\x1b\x43\x41NNOT_ADD_CLOSED_USER_LIST\x10\x1b\x12:\n6CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS\x10\x1c\x12\x35\n1CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS\x10\x1d\x12\x37\n3CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS\x10\x1e\x12\x31\n-CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS\x10\x1f\x12\x39\n5CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS\x10 \x12\x37\n3CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE\x10!\x12\x1b\n\x17INVALID_CUSTOM_AFFINITY\x10`\x12\x19\n\x15INVALID_CUSTOM_INTENT\x10\x61\x12\x16\n\x12INVALID_IP_ADDRESS\x10\"\x12\x15\n\x11INVALID_IP_FORMAT\x10#\x12\x16\n\x12INVALID_MOBILE_APP\x10$\x12\x1f\n\x1bINVALID_MOBILE_APP_CATEGORY\x10%\x12\x18\n\x14INVALID_CRITERION_ID\x10&\x12\x1b\n\x17\x43\x41NNOT_TARGET_CRITERION\x10\'\x12$\n CANNOT_TARGET_OBSOLETE_CRITERION\x10(\x12\"\n\x1e\x43RITERION_ID_AND_TYPE_MISMATCH\x10)\x12\x1c\n\x18INVALID_PROXIMITY_RADIUS\x10*\x12\"\n\x1eINVALID_PROXIMITY_RADIUS_UNITS\x10+\x12 \n\x1cINVALID_STREETADDRESS_LENGTH\x10,\x12\x1b\n\x17INVALID_CITYNAME_LENGTH\x10-\x12\x1d\n\x19INVALID_REGIONCODE_LENGTH\x10.\x12\x1d\n\x19INVALID_REGIONNAME_LENGTH\x10/\x12\x1d\n\x19INVALID_POSTALCODE_LENGTH\x10\x30\x12\x18\n\x14INVALID_COUNTRY_CODE\x10\x31\x12\x14\n\x10INVALID_LATITUDE\x10\x32\x12\x15\n\x11INVALID_LONGITUDE\x10\x33\x12\x36\n2PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL\x10\x34\x12\x1d\n\x19INVALID_PROXIMITY_ADDRESS\x10\x35\x12\x1c\n\x18INVALID_USER_DOMAIN_NAME\x10\x36\x12 \n\x1c\x43RITERION_PARAMETER_TOO_LONG\x10\x37\x12&\n\"AD_SCHEDULE_TIME_INTERVALS_OVERLAP\x10\x38\x12\x32\n.AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS\x10\x39\x12%\n!AD_SCHEDULE_INVALID_TIME_INTERVAL\x10:\x12\x30\n,AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT\x10;\x12/\n+AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS\x10<\x12$\n CANNOT_BID_MODIFY_CRITERION_TYPE\x10=\x12\x32\n.CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT\x10>\x12(\n$CANNOT_BID_MODIFY_NEGATIVE_CRITERION\x10?\x12\x1f\n\x1b\x42ID_MODIFIER_ALREADY_EXISTS\x10@\x12\x17\n\x13\x46\x45\x45\x44_ID_NOT_ALLOWED\x10\x41\x12(\n$ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE\x10\x42\x12.\n*CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY\x10\x43\x12\x1c\n\x18\x43\x41NNOT_EXCLUDE_CRITERION\x10\x44\x12\x1b\n\x17\x43\x41NNOT_REMOVE_CRITERION\x10\x45\x12\x1a\n\x16PRODUCT_SCOPE_TOO_LONG\x10\x46\x12%\n!PRODUCT_SCOPE_TOO_MANY_DIMENSIONS\x10G\x12\x1e\n\x1aPRODUCT_PARTITION_TOO_LONG\x10H\x12)\n%PRODUCT_PARTITION_TOO_MANY_DIMENSIONS\x10I\x12\x1d\n\x19INVALID_PRODUCT_DIMENSION\x10J\x12\"\n\x1eINVALID_PRODUCT_DIMENSION_TYPE\x10K\x12$\n INVALID_PRODUCT_BIDDING_CATEGORY\x10L\x12\x1c\n\x18MISSING_SHOPPING_SETTING\x10M\x12\x1d\n\x19INVALID_MATCHING_FUNCTION\x10N\x12\x1f\n\x1bLOCATION_FILTER_NOT_ALLOWED\x10O\x12$\n INVALID_FEED_FOR_LOCATION_FILTER\x10\x62\x12\x1b\n\x17LOCATION_FILTER_INVALID\x10P\x12\x32\n.CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP\x10Q\x12\x39\n5HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION\x10R\x12\x41\n=HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION\x10S\x12.\n*FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING\x10T\x12\x1d\n\x19INVALID_WEBPAGE_CONDITION\x10U\x12!\n\x1dINVALID_WEBPAGE_CONDITION_URL\x10V\x12)\n%WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY\x10W\x12.\n*WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL\x10X\x12.\n*WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS\x10Y\x12\x45\nAWEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING\x10Z\x12\x31\n-WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX\x10[\x12/\n+WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX\x10\\\x12\x39\n5WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED\x10]\x12<\n8WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION\x10^\x12\x37\n3WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP\x10_B\xee\x01\n\"com.google.ads.googleads.v2.errorsB\x13\x43riterionErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CRITERIONERRORENUM_CRITERIONERROR = _descriptor.EnumDescriptor(
  name='CriterionError',
  full_name='google.ads.googleads.v2.errors.CriterionErrorEnum.CriterionError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCRETE_TYPE_REQUIRED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EXCLUDED_CATEGORY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_KEYWORD_TEXT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_TEXT_TOO_LONG', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_HAS_TOO_MANY_WORDS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_HAS_INVALID_CHARS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEMENT_URL', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_LIST', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_INTEREST', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FORMAT_FOR_PLACEMENT_URL', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_URL_IS_TOO_LONG', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_URL_HAS_ILLEGAL_CHAR', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TOPIC_PATH', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_YOUTUBE_CHANNEL_ID', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_YOUTUBE_VIDEO_ID', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_VERTICAL_CHANNEL_DEPRECATED', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_URL_UNSUPPORTED', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXCLUDE_CRITERIA_TYPE', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_CRITERIA_TYPE', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PRODUCT_FILTER', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_FILTER_TOO_LONG', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXCLUDE_SIMILAR_USER_LIST', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_CLOSED_USER_LIST', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CUSTOM_AFFINITY', index=34, number=96,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CUSTOM_INTENT', index=35, number=97,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_IP_ADDRESS', index=36, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_IP_FORMAT', index=37, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MOBILE_APP', index=38, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MOBILE_APP_CATEGORY', index=39, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CRITERION_ID', index=40, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_TARGET_CRITERION', index=41, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_TARGET_OBSOLETE_CRITERION', index=42, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITERION_ID_AND_TYPE_MISMATCH', index=43, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROXIMITY_RADIUS', index=44, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROXIMITY_RADIUS_UNITS', index=45, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STREETADDRESS_LENGTH', index=46, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CITYNAME_LENGTH', index=47, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REGIONCODE_LENGTH', index=48, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REGIONNAME_LENGTH', index=49, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_POSTALCODE_LENGTH', index=50, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_COUNTRY_CODE', index=51, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LATITUDE', index=52, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LONGITUDE', index=53, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL', index=54, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROXIMITY_ADDRESS', index=55, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_DOMAIN_NAME', index=56, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITERION_PARAMETER_TOO_LONG', index=57, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE_TIME_INTERVALS_OVERLAP', index=58, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS', index=59, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE_INVALID_TIME_INTERVAL', index=60, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT', index=61, number=59,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS', index=62, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_BID_MODIFY_CRITERION_TYPE', index=63, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT', index=64, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_BID_MODIFY_NEGATIVE_CRITERION', index=65, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_MODIFIER_ALREADY_EXISTS', index=66, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ID_NOT_ALLOWED', index=67, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE', index=68, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY', index=69, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXCLUDE_CRITERION', index=70, number=68,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_CRITERION', index=71, number=69,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_SCOPE_TOO_LONG', index=72, number=70,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_SCOPE_TOO_MANY_DIMENSIONS', index=73, number=71,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_PARTITION_TOO_LONG', index=74, number=72,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_PARTITION_TOO_MANY_DIMENSIONS', index=75, number=73,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PRODUCT_DIMENSION', index=76, number=74,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PRODUCT_DIMENSION_TYPE', index=77, number=75,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PRODUCT_BIDDING_CATEGORY', index=78, number=76,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_SHOPPING_SETTING', index=79, number=77,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_MATCHING_FUNCTION', index=80, number=78,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FILTER_NOT_ALLOWED', index=81, number=79,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FEED_FOR_LOCATION_FILTER', index=82, number=98,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_FILTER_INVALID', index=83, number=80,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP', index=84, number=81,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION', index=85, number=82,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION', index=86, number=83,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING', index=87, number=84,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_WEBPAGE_CONDITION', index=88, number=85,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_WEBPAGE_CONDITION_URL', index=89, number=86,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY', index=90, number=87,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL', index=91, number=88,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS', index=92, number=89,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING', index=93, number=90,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX', index=94, number=91,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX', index=95, number=92,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED', index=96, number=93,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION', index=97, number=94,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP', index=98, number=95,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=148,
  serialized_end=3877,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONERRORENUM_CRITERIONERROR)


_CRITERIONERRORENUM = _descriptor.Descriptor(
  name='CriterionErrorEnum',
  full_name='google.ads.googleads.v2.errors.CriterionErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONERRORENUM_CRITERIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=3877,
)

_CRITERIONERRORENUM_CRITERIONERROR.containing_type = _CRITERIONERRORENUM
DESCRIPTOR.message_types_by_name['CriterionErrorEnum'] = _CRITERIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionErrorEnum = _reflection.GeneratedProtocolMessageType('CriterionErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.criterion_error_pb2'
  ,
  __doc__ = """Container for enum describing possible criterion errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.CriterionErrorEnum)
  ))
_sym_db.RegisterMessage(CriterionErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
